@@ -1,10 +1,12 @@
 package Firewall::Config::Connector::Device::Cisco;
 
-use Carp;
-use Expect;
+#------------------------------------------------------------------------------
+# 加载系统模块
+#------------------------------------------------------------------------------
 use Moose;
-use Try::Tiny;
 use namespace::autoclean;
+use Try::Tiny;
+use Expect;
 
 #------------------------------------------------------------------------------
 # 定义设备 Connector 通用属性
